# frozen_string_literal: true

#
# This function checks if artifact exists in the specified location.
#
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function(:'wls_install::artifact_exists') do
  dispatch :artifact_exists do
    param 'String', :domain_dir
    param 'String', :type
    param 'String', :wls_object
    optional_param 'String', :sub_type
    return_type 'Boolean'
  end

  def artifact_exists(domain_dir, type, wls_object, sub_type = '')
    return false if %w[resource resource_entry].include?(type) && sub_type.empty?

    scope = closure_scope
    fact = scope['wls_install_domains']
    if fact.empty?
      call_function('wls_install::log', 'wls_install::artifact_exists wls_install_domains empty, return false')
    else
      fact.each_key do |domain|
        next unless fact[domain]['path'] == domain_dir

        case type
        when 'jdbc'
          jdbc = fact[domain]['jdbc']
          return true if !jdbc.empty? && jdbc.include?(wls_object)

        when 'cluster'
          clusters = fact[domain]['clusters']
          return true if !clusters.empty? && clusters.include?(wls_object)

        when 'coherence'
          coherence_cluster = fact[domain]['coherence_clusters']
          return true if !coherence_cluster.empty? && coherence_cluster.include?(wls_object)

        when 'server'
          servers = fact[domain]['servers']
          return true if !servers.empty? && servers.include?(wls_object)

        when 'machine'
          servers = fact[domain]['servers']
          unless servers.empty?
            servers.each do |server|
              server.each do |entry|
                return true if entry['machine'] == wls_object
              end
            end
          end

        when 'server_templates'
          server_templates = fact[domain]['templates']
          return true if !server_templates.empty? && server_templates.include?(wls_object)

        when 'resource'
          adapter = wls_object.downcase
          plan = sub_type.strip

          plan_value = fact[domain]["eis_#{adapter}_plan"]
          return true if !plan_value.empty? && plan_value.include?(plan)

        when 'resource_entry'
          adapter = wls_object.downcase
          entry = sub_type.strip

          plan_entries = fact[domain]["eis_#{adapter}_entries"]
          return true if !plan_entries.empty? && plan_entries.include?(entry)

        when 'deployments'
          deployments = fact[domain]['deployments']
          return true if !deployments.empty? && deployments.include?(wls_object)

        when 'filestore'
          filestores = fact[domain]['filestores']
          return true if !filestores.empty? && filestores.include?(wls_object)

        when 'jdbcstore'
          jdbcstores = fact[domain]['jdbcstores']
          return true if !jdbcstores.empty? && jdbcstores.include?(wls_object)

        when 'safagent'
          safagents = fact[domain]['safagents']
          return true if !safagents.empty? && safagents.include?(wls_object)

        when 'jmsserver'
          jmsservers = fact[domain]['jmsservers']
          return true if !jmsservers.empty? && jmsservers.include?(wls_object)

        when 'jmsmodule'
          jmsmodules = fact[domain]['jmsmodules']
          return true if !jmsmodules.empty? && jmsmodules.include?(wls_object)

        when 'jmsobject'
          jmsmodules = fact[domain]['jmsmodules']
          unless jmsmodules.empty?
            jmsmodules.each do |jmsmodule|
              jmsmodule.each do |jmsentry|
                jmsobjects = jmsentry['objects']
                next if jmsobjects.nil?

                return true if !jmsobjects.empty? && jmsobjects.include?(wls_object)
              end
            end
          end

        when 'jmssubdeployment'
          jmsmodules = fact[domain]['jmsmodules']
          unless jmsmodules.empty?
            jmsmodules.each do |jmsmodule|
              jmsmodule.each do |jmsentry|
                subdeployments = jmsentry['subdeployments']
                next if subdeployments.nil?

                return true if !subdeployments.empty? && subdeployments.include?(wls_object)
              end
            end
          end

        when 'jmsquota'
          jmsmodules = fact[domain]['jmsmodules']
          unless jmsmodules.empty?
            jmsmodules.each do |jmsmodule|
              jmsmodule.each do |jmsentry|
                quotas = jmsentry['quotas']
                next if quotas.nil?

                return true if !quotas.empty? && quotas.include?(wls_object)
              end
            end
          end

        when 'foreignserver'
          jmsmodules = fact[domain]['jmsmodules']
          unless jmsmodules.empty?
            jmsmodules.each do |jmsmodule|
              jmsmodule.each do |jmsentry|
                foreign_servers = jmsentry['foreign_servers']
                next if foreign_servers.nil?

                return true if !foreign_servers.empty? && foreign_servers.include?(wls_object)
              end
            end
          end

        when 'foreignserver_object'
          jmsmodules = fact[domain]['jmsmodules']
          unless jmsmodules.empty?
            jmsmodules.each do |jmsmodule|
              jmsmodule.each do |jmsentry|
                foreign_servers = jmsentry['foreign_servers']
                next if foreign_servers.nil?

                next if foreign_servers.empty?

                foreign_servers.each do |value|
                  foreign_server_objects = value['objects']
                  next if foreign_server_objects.nil?

                  return true if !foreign_server_objects.empty? && foreign_server_objects.include?(wls_object)
                end
              end
            end
          end

        end
      end
    end
    false
  end
end
