#
# wls_install::domain
#
# @summary This defined type allows you create a WebLogic domain.
# It supports the following WebLogic versions:
# - 1036
# - 1111
# - 1211
# - 1212
# - 1213
# 
# You can specify a domain template, thus specifying what kind of domain will be created. Using the template, you can create a Fusion Middleware enabled domain. The defined type supports the following templates:
# - Standard
# - Adf
# - Osb
# - osb_soa
# - osb_soa_bpm
# - soa
# - soa_bpm
# 
# Here is an example on how you could use this:
# 
# ```puppet
# orawls::domain { 'wlsDomain12c':
#   version                     => 1212
#   weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
#   middleware_home_dir         => "/opt/oracle/middleware12c",
#   jdk_home_dir                => "/usr/java/jdk1.7.0_45",
#   domain_template             => "standard", 
#   domain_name                 => "Wls12c",
#   development_mode            => false,
#   adminserver_name            => "AdminServer",
#   adminserver_address         => "localhost",
#   adminserver_port            => 7001,
#   nodemanager_secure_listener => true,
#   nodemanager_port            => 5556,
#   java_arguments              => { "ADM" => "...", "OSB" => "...", "SOA" => "...", "BAM" => "..."},
#   weblogic_user               => "weblogic",
#   weblogic_password           => "weblogic1",
#   os_user                     => "oracle",
#   os_group                    => "dba",
#   log_dir                     => "/data/logs",
#   download_dir                => "/data/install",
# }
# 
# ```
#
# @param [Wls_install::Versions] version
#    The version that is installed in the used Oracle home.
#    Puppet uses this value to decide on version specific actions.
#
# @param [Stdlib::Absolutepath] weblogic_home_dir
#    Directory to use as WebLogic home.
#
# @param [Stdlib::Absolutepath] middleware_home_dir
#    Middleware home directory.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [Variant[Integer[7, 7], Integer[8, 8]]] jdk_major_version
#    Major version of JDK to use.
#
# @param [Optional[Stdlib::Absolutepath]] wls_domains_dir
#    The root directory where all domain directories reside in.
#
# @param [Optional[Stdlib::Absolutepath]] wls_apps_dir
#    The root directory where all aplication directories reside in.
#
# @param [Enum['standard',
#     'ohs_standalone',
#     'adf_restricted',
#     'osb',
#     'osb_soa',
#     'osb_soa_bpm',
#     'soa',
#     'soa_bpm',
#     'bam',
#     'adf',
#     'oim',
#     'oud',
#     'wc',
#     'wc_wcc_bpm',
#     'forms',
#     'bip']] domain_template
#    Template you want to use for the domain.
#    Valid values are:
#    standard
#    ohs_standalone
#    adf_restricted
#    osb
#    osb_soa
#    osb_soa_bpm
#    soa
#    soa_bpm
#    bam
#    adf
#    oim
#    oud
#    wc
#    wc_wcc_bpm
#
# @param [Boolean] bam_enabled
#    Boolean to determine in BAM is enabled.
#
# @param [Boolean] b2b_enabled
#    Boolean to determine if b2b is eanbled.
#
# @param [Boolean] ess_enabled
#    Boolean to determine of ESS is enabled for the domain.
#
# @param [Boolean] owsm_enabled
#    Boolean to detrmine if owsm is enabled.
#
# @param [String[1]] domain_name
#    The domain name.
#
# @param [Boolean] development_mode
#    Boolean to determine if you want to create a development domain.
#
# @param [String[1]] adminserver_name
#    The name of the Admin Server.
#
# @param [String[1]] adminserver_machine_name
#    machine name you want to run the adminserver on.
#
# @param [String[1]] adminserver_address
#    The address of the admin server.
#    May be a DNS name or a physical IP address.
#
# @param [Integer] adminserver_port
#    The IP port the admin server is listening on.
#
# @param [Optional[Integer]] adminserver_ssl_port
#    SSL port to use for the Admin server.
#
# @param [Boolean] administration_port_enabled
#    Specifies whether the domain-wide administration port should be enabled for this WebLogic Server domain.
#    Because the administration port uses SSL, enabling the administration port requires that SSL must be configured for all servers in the domain.
#    The domain-wide administration port enables you to start a WebLogic Server instance in STANDBY state. It also allows you to separate administration traffic from application traffic in your domain. Because all servers in the domain must enable or disable the administration port at once, you configure the default administration port settings at the domain level.
#    If you enable the administration port:
#    The administration port accepts only connections that specify administrator credentials.
#    Connections that specify administrator credentials can use only the administration port.
#    The command that starts managed servers must specify a secure protocol and the administration port: -Dweblogic.management.server=https://admin_server:administration_port
#
# @param [Optional[Integer]] administration_port
#    The common secure administration port for this WebLogic Server domain.
#    (Requires you to enable the administration port.)
#
# @param [Boolean] adminserver_listen_on_all_interfaces
#    Boolean to determine if you want to let the adminserver listen on all interfaces.
#
# @param [Hash] java_arguments
#    Arguments to use when calling java.
#
# @param [Optional[String[1]]] nodemanager_address
#    Address the nodemanager is running on.
#    This may be a DNS name or a physical IP address.
#
# @param [Integer] nodemanager_port
#    The IP port the nodemanager is listening on.
#
# @param [Boolean] nodemanager_secure_listener
#    Use SSL for listening.
#
# @param [String[1]] weblogic_user
#    The base WebLogic username to configure.
#
# @param [Easy_type::Password] weblogic_password
#    The password of the base WebLogic user name.
#
# @param [Optional[String[1]]] nodemanager_username
#    Username to use for nodemananer.
#
# @param [Optional[Easy_type::Password]] nodemanager_password
#    Password to use for nodemanager.
#
# @param [Optional[Easy_type::Password]] domain_password
#    Password to use for the domain.
#
# @param [Boolean] jsse_enabled
#    Determine if you want to enable JSSE security.
#
# @param [Boolean] webtier_enabled
#    Boolean to determine if you want to enable the WebTier.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [Optional[Stdlib::Absolutepath]] log_dir
#    Directory to use for logging.
#
# @param [Optional[String[1]]] repository_database_url
#    The jdbc URL of the RCU repository.
#
# @param [Optional[String[1]]] rcu_database_url
#    Database URL to create the RCU on.
#
# @param [Optional[Boolean]] rcu_honor_omf
#    Boolean to determine if you want the RCU creation to honor OMF (Oracle Managed Files).
#
# @param [Optional[Enum['SMALL', 'MED', 'LARGE']]] rcu_soa_profile
#    Profile to use for creating the RCU for SOA.
#
# @param [Optional[String[1]]] rcu_tablespace
#    The default tablespace to use for the RCU created accounts.
#
# @param [Optional[String[1]]] rcu_temp_tablespace
#    The temporary tablespace to use for the RCU created accounts.
#
# @param [String[1]] repository_prefix
#    Extra prefix to use for the RCU.
#
# @param [Optional[Easy_type::Password]] repository_password
#    The password to use for accessing the RCU repository.
#
# @param [String[1]] repository_sys_user
#    SYS username to use on the database where the RCU repository is created.
#    Default is 'SYS'
#    Default is 'SYS'
#
# @param [Optional[Easy_type::Password]] repository_sys_password
#    SYS password to use on the database where the RCU repository is created.
#
# @param [Boolean] custom_trust
#    Determine if you want to use a custom trust or not.
#
# @param [Optional[String[1]]] trust_keystore_file
#    File specificiation of the trust keystore.
#
# @param [Optional[Easy_type::Password]] trust_keystore_passphrase
#    Passphrase to use for the trust keystore.
#
# @param [Boolean] custom_identity
#    Determine if you want to use a custom identity store or not.
#
# @param [Optional[String[1]]] custom_identity_keystore_filename
#    file name of the keystore identity file.
#
# @param [Optional[Easy_type::Password]] custom_identity_keystore_passphrase
#    Passphrase to use when opening the identity keystore.
#
# @param [Optional[String[1]]] custom_identity_alias
#    Alias for custom identity.
#
# @param [Optional[Easy_type::Password]] custom_identity_privatekey_passphrase
#    Private passphrase to use when opening the identity keystore.
#
# @param [Boolean] create_rcu
#    Determine if you want to create a RCU for the current domain.
#
# @param [Optional[String[1]]] ohs_standalone_listen_address
#    Listen address for OHS standlone server.
#
# @param [Optional[Integer]] ohs_standalone_listen_port
#    Listen port for OHS standlone server.
#
# @param [Optional[Integer]] ohs_standalone_ssl_listen_port
#    SSL Listen port for OHS standlone server.
#
# @param [Optional[String[1]]] wls_domains_file
#    file containing the current domains available on the system.
#
# @param [String[1]] puppet_os_user
#    The Puppet OS user to use.
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::domain (
  Wls_install::Versions          $version                               = lookup({name => 'wls_version', default_value => 1111}),
  Stdlib::Absolutepath           $weblogic_home_dir                     = lookup({name => 'wls_weblogic_home_dir'}),
  Stdlib::Absolutepath           $middleware_home_dir                   = lookup({name => 'wls_middleware_home_dir'}),
  Stdlib::Absolutepath           $jdk_home_dir                          = lookup({name => 'wls_jdk_home_dir'}),
  Variant[
    Integer[7,7],
    Integer[8,8]
  ]                              $jdk_major_version                     = lookup({name => 'wls_jdk_major_version', default_value => 7}),
  Optional[Stdlib::Absolutepath] $wls_domains_dir                       = lookup({name => 'wls_domains_dir', default_value => undef}),
  Optional[Stdlib::Absolutepath] $wls_apps_dir                          = lookup({name => 'wls_apps_dir', default_value => undef}),
  Enum[
    'standard',
    'ohs_standalone',
    'adf_restricted',
    'osb',
    'osb_soa',
    'osb_soa_bpm',
    'soa',
    'soa_bpm',
    'bam',
    'adf',
    'oim',
    'oud',
    'wc',
    'wc_wcc_bpm',
    'forms',
    'bip'
  ]                              $domain_template                       = lookup({name => 'domain_template', default_value => 'standard'}),
  Boolean                        $bam_enabled                           = true,
  Boolean                        $b2b_enabled                           = false,
  Boolean                        $ess_enabled                           = false,
  Boolean                        $owsm_enabled                          = false,
  String[1]                      $domain_name                           = lookup({name => 'domain_name'}),
  Boolean                        $development_mode                      = true,
  String[1]                      $adminserver_name                      = lookup({name => 'domain_adminserver', default_value => 'AdminServer'}),
  String[1]                      $adminserver_machine_name              = lookup({name => 'domain_adminserver_machine_name', default_value => 'LocalMachine'}),
  String[1]                      $adminserver_address                   = lookup({name => 'domain_adminserver_address', default_value => undef}),
  Integer                        $adminserver_port                      = lookup({name => 'domain_adminserver_port', default_value => 7001}),
  Optional[Integer]              $adminserver_ssl_port                  = undef,
  Optional[Integer]              $administration_port                   = undef,
  Boolean                        $administration_port_enabled           = false,
  Boolean                        $adminserver_listen_on_all_interfaces  = false,
  Hash                           $java_arguments                        = lookup({name => 'domain_java_arguments', default_value => {}}),
  Optional[String[1]]            $nodemanager_address                   = undef,
  Integer                        $nodemanager_port                      = lookup({name => 'domain_nodemanager_port', default_value => 5556}),
  Boolean                        $nodemanager_secure_listener           = true,
  String[1]                      $weblogic_user                         = lookup({name => 'wls_weblogic_user', default_value => 'weblogic'}),
  Easy_type::Password            $weblogic_password                     = lookup({name => 'domain_wls_password'}),
  Optional[String[1]]            $nodemanager_username                  = undef,
  Optional[Easy_type::Password]  $nodemanager_password                  = undef,
  Optional[Easy_type::Password]  $domain_password                       = undef,
  Boolean                        $jsse_enabled                          = lookup({name => 'wls_jsse_enabled', default_value => false}),
  Boolean                        $webtier_enabled                       = false,
  String[1]                      $os_user                               = lookup({name => 'wls_os_user'}),
  String[1]                      $os_group                              = lookup({name => 'wls_os_group'}),
  Stdlib::Absolutepath           $download_dir                          = lookup({name => 'wls_download_dir'}),
  Optional[Stdlib::Absolutepath] $log_dir                               = lookup({name => 'wls_log_dir', default_value => undef}),
  Optional[String[1]]            $repository_database_url               = lookup({name => 'repository_database_url', default_value => undef}),
  Optional[String[1]]            $rcu_database_url                      = undef,
  Optional[Boolean]              $rcu_honor_omf                         = undef,
  Optional[String[1]]            $rcu_temp_tablespace                   = undef,
  Optional[String[1]]            $rcu_tablespace                        = undef,
  Optional[
    Enum[
      'SMALL',
      'MED',
      'LARGE'
    ]
  ]                              $rcu_soa_profile                       = undef,
  String[1]                      $repository_prefix                     = lookup({name => 'repository_prefix', default_value => 'DEV'}),
  Optional[Easy_type::Password]  $repository_password                   = lookup({name => 'repository_password', default_value => undef}),
  String[1]                      $repository_sys_user                   = 'sys',
  Optional[Easy_type::Password]  $repository_sys_password               = undef,
  Boolean                        $custom_trust                          = lookup({name => 'wls_custom_trust', default_value => false}),
  Optional[String[1]]            $trust_keystore_file                   = lookup({name => 'wls_trust_keystore_file', default_value => undef}),
  Optional[Easy_type::Password]  $trust_keystore_passphrase             = lookup({name => 'wls_trust_keystore_passphrase', default_value => undef}),
  Boolean                        $custom_identity                       = false,
  Optional[String[1]]            $custom_identity_keystore_filename     = undef,
  Optional[Easy_type::Password]  $custom_identity_keystore_passphrase   = undef,
  Optional[String[1]]            $custom_identity_alias                 = undef,
  Optional[Easy_type::Password]  $custom_identity_privatekey_passphrase = undef,
  Boolean                        $create_rcu                            = lookup({name => 'create_rcu', default_value => true}),
  Optional[String[1]]            $ohs_standalone_listen_address         = undef,
  Optional[Integer]              $ohs_standalone_listen_port            = undef,
  Optional[Integer]              $ohs_standalone_ssl_listen_port        = undef,
  Optional[String[1]]            $wls_domains_file                      = undef,
  String[1]                      $puppet_os_user                        = 'root',
  Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]                              $log_output                            = undef,
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                              $logoutput                             = lookup({name => 'logoutput', default_value => 'on_failure'}),
  Optional[Boolean]              $wls_apps_inside_domain                = false,
  Optional[Boolean]              $crossdomain_enabled                   = true,
)
{
  $root_group = lookup('wls_install::root_group', String[1])

  if ( $wls_domains_file ){
    $wls_domains_file_location = $wls_domains_file
  } else {
    $wls_domains_file_location = '/etc/wls_domains.dat'
  }

  if ( $wls_domains_dir ) {
    $domains_dir =  $wls_domains_dir
  } else {
    $domains_dir = "${middleware_home_dir}/user_projects/domains"
  }

  if ( $wls_apps_inside_domain == false ) and ( ($wls_apps_dir == undef) or ($wls_apps_dir == '') ) {
    $apps_dir = "${middleware_home_dir}/user_projects/applications"
  } elsif ( $wls_apps_inside_domain == true ) {
    $apps_dir =  undef
    debug("orawls::domain ${title} wls_apps_inside_domain is set to true so applications will be located at ${wls_domains_dir}/${domain_name}/applications" )
  } else {
    $apps_dir =  $wls_apps_dir
  }

  $domain_dir = "${domains_dir}/${domain_name}"

  case $::kernel {
    'Linux', 'AIX': {
      $ora_inst_path = '/etc'
    }
    'SunOS': {
      $ora_inst_path = '/var/opt/oracle'
    }
    default: {
      fail("Unrecognized operating system ${::kernel}, please use it on a Linux host")
    }
  }
  easy_type::debug_evaluation() # Show local variable on extended debug

  unless ( wls_install::domain_exists($domain_dir) ) {
    unless ( $log_dir ) {
      $admin_nodemanager_log_dir            = "${domain_dir}/servers/${adminserver_name}/logs"
      $node_mgr_log_dir                     = "${domain_dir}/nodemanager/nodemanager.log"
      $osb_nodemanager_log_dir              = "${domain_dir}/servers/osb_server1/logs"
      $soa_nodemanager_log_dir              = "${domain_dir}/servers/soa_server1/logs"
      $bam_nodemanager_log_dir              = "${domain_dir}/servers/bam_server1/logs"
      $ess_nodemanager_log_dir              = "${domain_dir}/servers/ess_server1/logs"
      $oim_nodemanager_log_dir              = "${domain_dir}/servers/oim_server1/logs"
      $oam_nodemanager_log_dir              = "${domain_dir}/servers/oam_server1/logs"
      $bi_nodemanager_log_dir               = "${domain_dir}/servers/bi_server1/logs"
      $wc_collaboration_nodemanager_log_dir = "${domain_dir}/servers/WC_Collaboration/logs"
      $wc_portlet_nodemanager_log_dir       = "${domain_dir}/servers/WC_Portlet/logs"
      $wc_spaces_nodemanager_log_dir        = "${domain_dir}/servers/WC_Spaces/logs"
      $umc_nodemanager_log_dir              = "${domain_dir}/servers/UCM_server1/logs"
    } else {
      $admin_nodemanager_log_dir = $osb_nodemanager_log_dir = $soa_nodemanager_log_dir = $bam_nodemanager_log_dir = $ess_nodemanager_log_dir = $oim_nodemanager_log_dir = $oam_nodemanager_log_dir = $bi_nodemanager_log_dir = $_c= $wc_portlet_nodemanager_log_dir = $wc_spaces_nodemanager_log_dir = $umc_nodemanager_log_dir = $log_dir
      $node_mgr_log_dir          = "${log_dir}/nodemanager_${domain_name}.log"

      # create all log folders
      unless ( defined(Exec["create ${log_dir} directory"]) ) {
        exec { "create ${log_dir} directory":
          command   => "/bin/mkdir -p ${log_dir}",
          unless    => "/bin/test -d ${log_dir}",
          user      => $puppet_os_user,
          logoutput => $logoutput,
        }
      }

      unless ( defined(File[$log_dir]) ) {
        file { $log_dir:
          ensure  => directory,
          require => Exec["create ${log_dir} directory"],
          mode    => '0775',
          owner   => $os_user,
          group   => $os_group,
        }
      }
    }
    $template_spaces     = "${middleware_home_dir}/Oracle_WC1/common/templates/applications/oracle.wc_spaces_template_11.1.1.jar"
    $template_bpm_spaces = "${middleware_home_dir}/Oracle_WC1/common/templates/applications/oracle.bpm.spaces_template_11.1.1.jar"
    $template_portlets   = "${middleware_home_dir}/Oracle_WC1/common/templates/applications/oracle.producer_apps_template_11.1.1.jar"
    $template_pagelet    = "${middleware_home_dir}/Oracle_WC1/common/templates/applications/oracle.pagelet-producer_template_11.1.1.jar"
    $template_discussion = "${middleware_home_dir}/Oracle_WC1/common/templates/applications/oracle.owc_discussions_template_11.1.1.jar"
    $template_ucm        = "${middleware_home_dir}/Oracle_WCC1/common/templates/applications/oracle.ucm.cs_template_11.1.1.jar"

    case $version {
      1036, 1111: {
        $template_coherence    = undef
        $template              = "${weblogic_home_dir}/common/templates/domains/wls.jar"
        $template_ws           = "${weblogic_home_dir}/common/templates/applications/wls_webservice.jar"
        $template_jax_ws       = "${weblogic_home_dir}/common/templates/applications/wls_webservice_jaxws.jar"
        $template_em           = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.em_11_1_1_0_0_template.jar"
        $template_jrf          = "${middleware_home_dir}/oracle_common/common/templates/applications/jrf_template_11.1.1.jar"
        $template_appl_core    = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.applcore.model.stub.11.1.1_template.jar"
        $template_wsmpm        = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.wsmpm_template_11.1.1.jar"
        $template_osb          = "${middleware_home_dir}/Oracle_OSB1/common/templates/applications/wlsb.jar"
        $template_owsm         = "${middleware_home_dir}/Oracle_OSB1/common/templates/applications/wlsb_owsm.jar"
        $template_soa_adapters = "${middleware_home_dir}/Oracle_OSB1/common/templates/applications/oracle.soa.common.adapters_template_11.1.1.jar"
        $template_soa          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.soa_template_11.1.1.jar"
        $template_bpm          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.bpm_template_11.1.1.jar"
        $template_bam          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.bam_template_11.1.1.jar"
        case $domain_template {
          'ohs_standalone': {
            fail("OHS Standalone domain configuration only works with version 12.1.2 or higher. Version ${version} not supported.")
          }
          'standard': {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
          }
          'osb': {
            $extensions_template_file = 'wls_install/domains/extensions/osb_template.py.epp'
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'ess_enabled' => $ess_enabled,
              'owsm_enabled' => $owsm_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'     => $template_em,
              'template_ws'     => $template_ws,
              'template_osb'    => $template_osb,
              'template_jrf'    => $template_jrf,
              'template_wsmpm'  => $template_wsmpm,
              'template_owsm'   => $template_owsm,
              'template_jax_ws' => $template_jax_ws,
            }
            $wlst_path                = "${middleware_home_dir}/Oracle_OSB1/common/bin"
          }
          'osb_soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = false
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'osb_soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa', 'soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'bam': {
            $extensions_template_file = 'wls_install/domains/extensions/bam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'bam_nodemanager_log_dir'   => $bam_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'adf', 'adf_restricted': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_jax_ws' => $template_jax_ws,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
          }
          'oim': {
            $extensions_template_file = 'wls_install/domains/extensions/oim_oam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_IDM1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'oam_nodemanager_log_dir' => $oam_nodemanager_log_dir,
              'oim_nodemanager_log_dir' => $oim_nodemanager_log_dir,
              'bi_nodemanager_log_dir' => $bi_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'oud': {
            $extensions_template_file = 'wls_install/domains/extensions/oud_template.py.epp'
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc': {
            $extensions_template_file = 'wls_install/domains/extensions/wc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WC1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc_wcc_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/wc_wcc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WCC1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'umc_nodemanager_log_dir' => $umc_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
              'template_ucm' => $template_ucm,
              'template_bpm_spaces' => $template_bpm_spaces,
            }
          }
          default: {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
          }
        }
        $rcu_supported            = false
      }
      1112: {
        $template_coherence    = undef
        $template              = "${weblogic_home_dir}/common/templates/domains/wls.jar"
        $template_ws           = "${weblogic_home_dir}/common/templates/applications/wls_webservice.jar"
        $template_em           = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.em_11_1_1_0_0_template.jar"
        $template_jrf          = "${middleware_home_dir}/oracle_common/common/templates/applications/jrf_template_11.1.1.jar"
        $template_appl_core    = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.applcore.model.stub.11.1.1_template.jar"
        $template_wsmpm        = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.wsmpm_template_11.1.1.jar"
        # MW: do we use those three variables anywhere?
        $template_oim           = "${middleware_home_dir}/Oracle_IDM1/common/templates/applications/oracle.oim_11.1.2.0.0_template.jar"
        $template_oam           = "${middleware_home_dir}/Oracle_IDM1/common/templates/applications/oracle.oam_ds_11.1.2.0.0_template.jar"
        $template_oud           = "${middleware_home_dir}/Oracle_OUD1/common/templates/applications/oracle.odsm_11.1.1.5.0_template.jar"
        # END OF MW
        $template_osb          = "${middleware_home_dir}/Oracle_OSB1/common/templates/applications/wlsb.jar"
        $template_soa_adapters = "${middleware_home_dir}/Oracle_OSB1/common/templates/applications/oracle.soa.common.adapters_template_11.1.1.jar"
        $template_soa          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.soa_template_11.1.1.jar"
        $template_bpm          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.bpm_template_11.1.1.jar"
        $template_bam          = "${middleware_home_dir}/Oracle_SOA1/common/templates/applications/oracle.bam_template_11.1.1.jar"
        case $domain_template {
          'ohs_standalone': {
            fail("OHS Standalone domain configuration only works with version 12.1.2 or higher. Version ${version} not supported.")
          }
          'standard': {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
          }
          'osb': {
            $extensions_template_file = 'wls_install/domains/extensions/osb_template.py.epp'
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'ess_enabled' => $ess_enabled,
              'owsm_enabled' => $owsm_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'     => $template_em,
              'template_ws'     => $template_ws,
              'template_osb'    => $template_osb,
              'template_jrf'    => $template_jrf,
              'template_wsmpm'  => $template_wsmpm,
            }
            $wlst_path                = "${middleware_home_dir}/Oracle_OSB1/common/bin"
          }
          'osb_soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = false
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version'  => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port'   => $nodemanager_port,
            }
          }
          'osb_soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa', 'soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'bam': {
            $extensions_template_file = 'wls_install/domains/extensions/bam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'bam_nodemanager_log_dir'   => $bam_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'adf', 'adf_restricted': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
          }
          'oim': {
            $extensions_template_file = 'wls_install/domains/extensions/oim_oam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_IDM1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'oam_nodemanager_log_dir' => $oam_nodemanager_log_dir,
              'oim_nodemanager_log_dir' => $oim_nodemanager_log_dir,
              'bi_nodemanager_log_dir' => $bi_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'oud': {
            $extensions_template_file = 'wls_install/domains/extensions/oud_template.py.epp'
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc': {
            $extensions_template_file = 'wls_install/domains/extensions/wc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WC1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc_wcc_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/wc_wcc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WCC1/common/bin"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'umc_nodemanager_log_dir' => $umc_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
              'template_ucm' => $template_ucm,
              'template_bpm_spaces' => $template_bpm_spaces,
            }
          }
          default: {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
          }
        }
        $rcu_supported            = false
      }
      1212: {
        $template           = "${weblogic_home_dir}/common/templates/wls/wls.jar"
        $template_ws        = "${weblogic_home_dir}/common/templates/wls/wls_webservice.jar"
        $template_jax_ws    = "${weblogic_home_dir}/common/templates/wls/wls_webservice_jaxws.jar"
        $template_soap_jms  = "${weblogic_home_dir}/common/templates/wls/wls_webservice_soapjms.jar"
        $template_coherence = "${weblogic_home_dir}/common/templates/wls/wls_coherence.jar"
        $template_em        = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template_12.1.2.jar"
        $template_jrf       = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template_12.1.2.jar"
        $template_appl_core = "${middleware_home_dir}/oracle_common/common/templates/applications/oracle.applcore.model.stub.12.1.3_template.jar"
        $template_wsmpm     = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wsmpm_template_12.1.2.jar"
        $template_em_web_tr = "${middleware_home_dir}/em/common/templates/wls/oracle.em_webtier_template_12.1.2.jar"
        case $domain_template {
          'ohs_standalone': {
            $extensions_template_file = undef
            $wlst_path                = "${middleware_home_dir}/ohs/common/bin"
            $template_file            = 'wls_install/ohs/domain.py.epp'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_standalone_template_12.1.2.jar"
            $rcu_supported            = false
            $template_file_args       = {
              'domain_name'                    => $domain_name,
              'domain_dir'                     => $domain_dir,
              'template_ohs'                   => $template_ohs,
              'nodemanager_username'           => $nodemanager_username,
              'nodemanager_password'           => $nodemanager_password,
              'adminserver_address'            => $adminserver_address,
              'adminserver_port'               => $adminserver_port,
              'ohs_standalone_listen_address'  => $ohs_standalone_listen_address,
              'ohs_standalone_listen_port'     => $ohs_standalone_listen_port,
              'ohs_standalone_ssl_listen_port' => $ohs_standalone_ssl_listen_port,
            }
          }
          'standard': {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = false
          }
          'osb': {
            $extensions_template_file = 'wls_install/domains/extensions/osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_OSB1/common/bin"
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'ess_enabled' => $ess_enabled,
              'owsm_enabled' => $owsm_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em' => $template_em,
              'template_ws' => $template_ws,
              'template_jrf' => $template_jrf,
              'template_wsmpm' => $template_wsmpm,
              'template_jax_ws' => $template_jax_ws,
              'template_ohs' => $template_ohs,
              'template_soap_jms' => $template_soap_jms,
            }
          }
          'osb_soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_ohs'       => $template_ohs,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'osb_soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_ohs'       => $template_ohs,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_ohs'       => $template_ohs,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_ohs'       => $template_ohs,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'bam': {
            $extensions_template_file = 'wls_install/domains/extensions/bam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_SOA1/common/bin"
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'bam_nodemanager_log_dir'   => $bam_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'adf': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'adf'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
            $rcu_supported            = true
          }
          'adf_restricted': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = false
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
          }
          'oim': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oim_oam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_IDM1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'oam_nodemanager_log_dir' => $oam_nodemanager_log_dir,
              'oim_nodemanager_log_dir' => $oim_nodemanager_log_dir,
              'bi_nodemanager_log_dir' => $bi_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'oud': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oud_template.py.epp'
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WC1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc_wcc_bpm': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_wcc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WCC1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'umc_nodemanager_log_dir' => $umc_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
              'template_ucm' => $template_ucm,
              'template_bpm_spaces' => $template_bpm_spaces,
            }
          }
          default: {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = undef
            $wlst_path              = "${weblogic_home_dir}/common/bin"
            $template_ohs           = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.2.jar"
            $rcu_supported          = true
          }
        }
      }
      1213: {
        $template           = "${weblogic_home_dir}/common/templates/wls/wls.jar"
        $template_ws        = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-template_12.1.3.jar"
        $template_jax_ws    = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-jaxws-template_12.1.3.jar"
        $template_soap_jms  = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-soapjms-template_12.1.3.jar"
        $template_coherence = "${weblogic_home_dir}/common/templates/wls/wls_coherence_template_12.1.3.jar"
        $template_em        = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template_12.1.3.jar"
        $template_jrf       = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template_12.1.3.jar"
        $template_appl_core = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.applcore.model.stub.1.0.0_template.jar"
        $template_wsmpm     = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wsmpm_template_12.1.3.jar"
        $template_em_web_tr = "${middleware_home_dir}/em/common/templates/wls/oracle.em_webtier_template_12.1.3.jar"
        $template_ess_em    = "${middleware_home_dir}/em/common/templates/wls/oracle.em_ess_template_12.1.3.jar"
        $template_ess       = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.ess.basic_template_12.1.3.jar"
        $template_osb       = "${middleware_home_dir}/osb/common/templates/wls/oracle.osb_template_12.1.3.jar"
        $template_soa       = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa_template_12.1.3.jar"
        $template_bpm       = "${middleware_home_dir}/soa/common/templates/wls/oracle.bpm_template_12.1.3.jar"
        $template_bam       = "${middleware_home_dir}/soa/common/templates/wls/oracle.bam.server_template_12.1.3.jar"
        $template_b2b       = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa.b2b_template_12.1.3.jar"
        $template_health    = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa.healthcare_template_12.1.3.jar"
        case $domain_template {
          'ohs_standalone': {
            $extensions_template_file = undef
            $wlst_path                = "${middleware_home_dir}/ohs/common/bin"
            $template_file            = 'wls_install/ohs/domain.py.epp'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_standalone_template_12.1.3.jar"
            $rcu_supported            = false
            $template_file_args       = {
              'domain_name'                    => $domain_name,
              'domain_dir'                     => $domain_dir,
              'template_ohs'                   => $template_ohs,
              'nodemanager_username'           => $nodemanager_username,
              'nodemanager_password'           => $nodemanager_password,
              'adminserver_address'            => $adminserver_address,
              'adminserver_port'               => $adminserver_port,
              'ohs_standalone_listen_address'  => $ohs_standalone_listen_address,
              'ohs_standalone_listen_port'     => $ohs_standalone_listen_port,
              'ohs_standalone_ssl_listen_port' => $ohs_standalone_ssl_listen_port,
            }
          }
          'standard': {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = false
          }
          'osb': {
            $extensions_template_file = 'wls_install/domains/extensions/osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/osb/common/bin"
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'ess_enabled' => $ess_enabled,
              'owsm_enabled' => $owsm_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em' => $template_em,
              'template_ws' => $template_ws,
              'template_osb' => $template_osb,
              'template_jrf' => $template_jrf,
              'template_wsmpm' => $template_wsmpm,
              'template_jax_ws' => $template_jax_ws,
              'template_ohs' => $template_ohs,
              'template_soap_jms' => $template_soap_jms,
              'template_ess' => $template_ess,
              'template_ess_em' => $template_ess_em,
            }
          }
          'osb_soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/soa/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'osb_soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/soa/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/soa/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port'   => $nodemanager_port,
            }
          }
          'soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/soa/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port'   => $nodemanager_port,
            }
          }
          'bam': {
            $extensions_template_file = 'wls_install/domains/extensions/bam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/soa/common/bin"
            $rcu_domain_template      = 'soa'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'bam_nodemanager_log_dir'   => $bam_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'adf': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'adf'
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
          }
          'adf_restricted': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = false
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
          }
          'oim': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oim_oam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_IDM1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'oam_nodemanager_log_dir' => $oam_nodemanager_log_dir,
              'oim_nodemanager_log_dir' => $oim_nodemanager_log_dir,
              'bi_nodemanager_log_dir' => $bi_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'oud': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oud_template.py.epp'
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }

          }
          'wc': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WC1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc_wcc_bpm': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_wcc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_WCC1/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'umc_nodemanager_log_dir' => $umc_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
              'template_ucm' => $template_ucm,
              'template_bpm_spaces' => $template_bpm_spaces,
            }
          }
          default: {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template_12.1.3.jar"
            $rcu_supported            = true
          }
        }
      }
      1221, 12211, 12212, 12213, 12214, 14110: {
        $template           = "${weblogic_home_dir}/common/templates/wls/wls.jar"
        $template_ws        = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-template.jar"
        $template_jax_ws    = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-jaxws-template.jar"
        $template_soap_jms  = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wls-webservice-soapjms-template.jar"
        $template_coherence = "${weblogic_home_dir}/common/templates/wls/wls_coherence_template.jar"
        $template_appl_core = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.applcore.model.stub_template.jar"
        $template_wsmpm     = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.wsmpm_template.jar"
        $template_em_web_tr = "${middleware_home_dir}/em/common/templates/wls/oracle.em_webtier_template.jar"
        $template_ess_em    = "${middleware_home_dir}/em/common/templates/wls/oracle.em_ess_template.jar"
        $template_ess       = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.ess.basic_template.jar"
        $template_osb       = "${middleware_home_dir}/osb/common/templates/wls/oracle.osb_template.jar"
        $template_soa       = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa_template.jar"
        $template_bpm       = "${middleware_home_dir}/soa/common/templates/wls/oracle.bpm_template.jar"
        $template_bam       = "${middleware_home_dir}/soa/common/templates/wls/oracle.bam.server_template.jar"
        $template_b2b       = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa.b2b_template.jar"
        $template_health    = "${middleware_home_dir}/soa/common/templates/wls/oracle.soa.healthcare_template.jar"
        case $domain_template {
          'ohs_standalone': {
            $extensions_template_file = undef
            $wlst_path                = "${middleware_home_dir}/ohs/common/bin"
            $template_file            = 'wls_install/ohs/domain.py.epp'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_standalone_template.jar"
            $rcu_supported            = false
            $template_file_args       = {
              'domain_name'                    => $domain_name,
              'domain_dir'                     => $domain_dir,
              'template_ohs'                   => $template_ohs,
              'nodemanager_username'           => $nodemanager_username,
              'nodemanager_password'           => $nodemanager_password,
              'adminserver_address'            => $adminserver_address,
              'adminserver_port'               => $adminserver_port,
              'ohs_standalone_listen_address'  => $ohs_standalone_listen_address,
              'ohs_standalone_listen_port'     => $ohs_standalone_listen_port,
              'ohs_standalone_ssl_listen_port' => $ohs_standalone_ssl_listen_port,
            }
          }
          'standard': {
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = false
          }
          'forms': {
            $extensions_template_file = 'wls_install/domains/extensions/forms_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'forms'
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'osb': {
            $extensions_template_file = 'wls_install/domains/extensions/osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'ess_enabled' => $ess_enabled,
              'owsm_enabled' => $owsm_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em' => $template_em,
              'template_ws' => $template_ws,
              'template_osb' => $template_osb,
              'template_jrf' => $template_jrf,
              'template_wsmpm' => $template_wsmpm,
              'template_jax_ws' => $template_jax_ws,
              'template_ohs' => $template_ohs,
              'template_soap_jms' => $template_soap_jms,
              'template_ess' => $template_ess,
              'template_ess_em' => $template_ess_em,
            }
          }
          'osb_soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'osb_soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_osb_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'soa': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $bpm                      = false
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port'   => $nodemanager_port,
            }
          }
          'soa_bpm': {
            $extensions_template_file = 'wls_install/domains/extensions/soa_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $bpm                      = true
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'bpm'         => $bpm,
              'bam_enabled' => $bam_enabled,
              'b2b_enabled' => $b2b_enabled,
              'ess_enabled' => $ess_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'osb_nodemanager_log_dir' => $osb_nodemanager_log_dir,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'ess_nodemanager_log_dir' => $ess_nodemanager_log_dir,
              'bam_nodemanager_log_dir' => $bam_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'template_b2b'       => $template_b2b,
              'template_ohs'       => $template_ohs,
              'template_ess'       => $template_ess,
              'template_ess_em'    => $template_ess_em,
              'template_soap_jms'  => $template_soap_jms,
              'nodemanager_port'   => $nodemanager_port,
            }
          }
          'bam': {
            $extensions_template_file = 'wls_install/domains/extensions/bam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'soa'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'bam_nodemanager_log_dir'   => $bam_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'template_bam'       => $template_bam,
              'template_bpm'       => $template_bpm,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'adf': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $rcu_domain_template      = 'adf'
            $rcu_supported            = true
          }
          'adf_restricted': {
            $extensions_template_file = 'wls_install/domains/extensions/jrf_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_restricted_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_restricted_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_jrf_restricted_template.jar"
            $rcu_supported            = false
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'jsse_enabled' => $jsse_enabled,
              'webtier_enabled' => $webtier_enabled,
              'custom_identity' => $custom_identity,
              'development_mode' => $development_mode,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'restricted' => true,
              'template_jrf' => $template_jrf,
              'template_em' => $template_em,
              'template_ohs' => $template_ohs,
              'template_jax_ws' => $template_jax_ws,
              'template_soap_jms' => $template_soap_jms,
              'template_wsmpm' => $template_wsmpm,
              'jdk_major_version' => $jdk_major_version,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
            }
          }
          'oim': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oim_oam_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/Oracle_IDM1/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'soa_nodemanager_log_dir' => $soa_nodemanager_log_dir,
              'oam_nodemanager_log_dir' => $oam_nodemanager_log_dir,
              'oim_nodemanager_log_dir' => $oim_nodemanager_log_dir,
              'bi_nodemanager_log_dir' => $bi_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
              'template_em'        => $template_em,
              'template_ws'        => $template_ws,
              'template_osb'       => $template_osb,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_appl_core' => $template_appl_core,
              'template_soa'       => $template_soa,
              'nodemanager_port' => $nodemanager_port,
            }
          }
          'oud': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/oud_template.py.epp'
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
            }
          }
          'wc_wcc_bpm': {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = 'wls_install/domains/extensions/wc_wcc_template.py.epp'
            $wlst_path                = "${middleware_home_dir}/oracle_common/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
            $extensions_template_file_args = {
              'extensions_template_file'  => $extensions_template_file,
              'download_dir' => $download_dir,
              'weblogic_home_dir' => $weblogic_home_dir,
              'domain_dir' => $domain_dir,
              'domain_name' => $domain_name,
              'wls_apps_inside_domain' => $wls_apps_inside_domain,
              'apps_dir' => $apps_dir,
              'development_mode' => $development_mode,
              'custom_identity' => $custom_identity,
              'jsse_enabled' => $jsse_enabled,
              'version' => $version,
              'webtier_enabled' => $webtier_enabled,
              'adminserver_name' => $adminserver_name,
              'weblogic_user' => $weblogic_user,
              'weblogic_password' => $weblogic_password,
              'jdk_home_dir' => $jdk_home_dir,
              'nodemanager_secure_listener' => $nodemanager_secure_listener,
              'java_arguments' => $java_arguments,
              'repository_database_url' => $repository_database_url,
              'repository_prefix' => $repository_prefix,
              'repository_password' => $repository_password,
              'adminserver_machine_name' => $adminserver_machine_name,
              'adminserver_address' => $adminserver_address,
              'admin_nodemanager_log_dir' => $admin_nodemanager_log_dir,
              'umc_nodemanager_log_dir' => $umc_nodemanager_log_dir,
              'wc_collaboration_nodemanager_log_dir' => $wc_collaboration_nodemanager_log_dir,
              'wc_portlet_nodemanager_log_dir' => $wc_portlet_nodemanager_log_dir,
              'wc_spaces_nodemanager_log_dir' => $wc_spaces_nodemanager_log_dir,
              'template_em'        => $template_em,
              'template_jrf'       => $template_jrf,
              'template_wsmpm'     => $template_wsmpm,
              'template_spaces' => $template_spaces,
              'template_portlets' => $template_portlets,
              'template_pagelet' => $template_pagelet,
              'template_discussion' => $template_discussion,
              'jdk_major_version' => $jdk_major_version,
              'template_ucm' => $template_ucm,
              'template_bpm_spaces' => $template_bpm_spaces,
            }
          }
          'bip': {
            $extensions_template_file = undef
            $wlst_path                = "${middleware_home_dir}/bi/bin"
            $rcu_domain_template      = 'bip'
            $rcu_supported            = true
          }
          default: {
            if ( $create_rcu == undef or $create_rcu ) {
              fail("Unkown domain_template(${domain_template}) for rcu with version ${version}")
            }
            $extensions_template_file = undef
            $wlst_path                = "${weblogic_home_dir}/common/bin"
            $template_em              = "${middleware_home_dir}/em/common/templates/wls/oracle.em_wls_template.jar"
            $template_jrf             = "${middleware_home_dir}/oracle_common/common/templates/wls/oracle.jrf_template.jar"
            $template_ohs             = "${middleware_home_dir}/ohs/common/templates/wls/ohs_managed_template.jar"
            $rcu_supported            = true
          }
        }
      }
      default: {
        fail("Version ${version} not recognized and supported.")
      }
    }


    $exec_path = "${jdk_home_dir}/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin"

    unless ( $domain_template == 'ohs_standalone' ) {
      $template_file = 'wls_install/domains/domain.py.epp'
      $template_file_args = {
          'nodemanager_port'                      => $nodemanager_port,
          'adminserver_port'                      => $adminserver_port,
          'download_dir'                          => $download_dir,
          'weblogic_home_dir'                     => $weblogic_home_dir,
          'domain_dir'                            => $domain_dir,
          'domain_name'                           => $domain_name,
          'apps_dir'                              => $apps_dir,
          'jsse_enabled'                          => $jsse_enabled,
          'development_mode'                      => $development_mode,
          'version'                               => $version,
          'adminserver_name'                      => $adminserver_name,
          'weblogic_user'                         => $weblogic_user,
          'weblogic_password'                     => $weblogic_password,
          'jdk_home_dir'                          => $jdk_home_dir,
          'domain_password'                       => $domain_password,
          'nodemanager_username'                  => $nodemanager_username,
          'nodemanager_password'                  => $nodemanager_password,
          'java_arguments'                        => $java_arguments,
          'template'                              => $template,
          'admin_nodemanager_log_dir'             => $admin_nodemanager_log_dir,
          'adminserver_machine_name'              => $adminserver_machine_name,
          'adminserver_address'                   => $adminserver_address,
          'adminserver_ssl_port'                  => $adminserver_ssl_port,
          'administration_port_enabled'           => $administration_port_enabled,
          'administration_port'                   => $administration_port,
          'jdk_major_version'                     => $jdk_major_version,
          'template_coherence'                    => $template_coherence,
          'custom_identity'                       => $custom_identity,
          'custom_identity_privatekey_passphrase' => $custom_identity_privatekey_passphrase,
          'custom_identity_alias'                 => $custom_identity_alias,
          'custom_identity_keystore_passphrase'   => $custom_identity_keystore_passphrase,
          'custom_identity_keystore_filename'     => $custom_identity_keystore_filename,
          'custom_trust'                          => $custom_trust,
          'trust_keystore_passphrase'             => $trust_keystore_passphrase,
          'trust_keystore_file'                   => $trust_keystore_file,

          'adminserver_listen_on_all_interfaces'  => $adminserver_listen_on_all_interfaces,
          'nodemanager_secure_listener'           => $nodemanager_secure_listener,
          'crossdomain_enabled'                   => $crossdomain_enabled,
        }
    }
    # the utils.py used by the wlst
    unless ( defined(File["${download_dir}/utils.py"]) ) {
      file { "${download_dir}/utils.py":
        ensure  => present,
        path    => "${download_dir}/utils.py",
        content => epp('wls_install/domains/utils.py.epp',{}),
        replace => true,
        backup  => false,
        mode    => '0775',
        owner   => $os_user,
        group   => $os_group,
      }
    }

    if ( $extensions_template_file ) {
      file { "domain_extension.py ${domain_name} ${title}":
        ensure    => present,
        path      => "${download_dir}/domain_extension_${domain_name}.py",
        content   => epp($extensions_template_file, $extensions_template_file_args),
        replace   => true,
        backup    => false,
        mode      => '0775',
        show_diff => false,
        owner     => $os_user,
        group     => $os_group,
        before    => File["domain.py ${domain_name} ${title}"],
      }
    }

    if ($domain_template == 'bip') {
        file { 'bi-config':
          ensure    => present,
          path      => "${download_dir}/bi-config-resp",
          content   => epp('wls_install/domains/bi-config.epp',{
            'domain_name'       => $domain_name,
            'wls_domains_dir'   => $wls_domains_dir,
            'weblogic_user'     => $weblogic_user,
            'weblogic_password' => $weblogic_password,
            'rcu_database_url'  => $rcu_database_url,
            'repository_prefix' => $repository_prefix,
            'adminserver_port'  => $adminserver_port,
          }),
          replace   => true,
          backup    => false,
          mode      => '0775',
          show_diff => false,
          owner     => $os_user,
          group     => $os_group,
        }
      } else {
        # the domain.py used by the wlst
        file { "domain.py ${domain_name} ${title}":
          ensure    => present,
          path      => "${download_dir}/domain_${domain_name}.py",
          content   => epp($template_file, $template_file_args),
          replace   => true,
          backup    => false,
          mode      => '0775',
          show_diff => false,
          owner     => $os_user,
          group     => $os_group,
          require   => File["${download_dir}/utils.py"],
        }
      }

    if ( $domains_dir == "${middleware_home_dir}/user_projects/domains" ) {
      unless ( defined(File['weblogic_domain_folder']) ) {
        file { 'weblogic_domain_folder':
          ensure => directory,
          path   => "${middleware_home_dir}/user_projects",
          mode   => '0775',
          owner  => $os_user,
          group  => $os_group,
        }
        File['weblogic_domain_folder'] -> File[$domains_dir]
      }
    }

    unless ( defined(File[$domains_dir]) ) {
      file { $domains_dir:
        ensure => directory,
        mode   => '0775',
        owner  => $os_user,
        group  => $os_group,
      }
    }

    if ( $wls_apps_inside_domain ) {
      unless ( defined(File["${domain_dir}/applications"]) ) {
        file { "${domain_dir}/applications":
          ensure  => directory,
          mode    => '0775',
          owner   => $os_user,
          group   => $os_group,
          require => Exec["execwlst ${domain_name} ${title}"],
        }
      }
    } elsif ( $apps_dir ) {
        unless ( defined(File[$apps_dir]) ) {
          file { $apps_dir:
            ensure  => directory,
            mode    => '0775',
            owner   => $os_user,
            group   => $os_group,
            require => Exec["execwlst ${domain_name} ${title}"],
          }
        }
    }

    # FMW RCU only for wls 12.1.2 or higher and when template is not standard, adf_restricted or ohs_standalone
    if ( $rcu_supported ) {

      if  $create_rcu {

        # only works for a 12c middleware home
        # creates RCU for ADF
        if !( $rcu_database_url and $repository_sys_password.unwrap and $repository_password.unwrap and $repository_prefix ){
          fail('Not all RCU parameters are provided')
        }

        wls_install::utils::rcu{ "RCU_12c ${title}":
          version                     => $version,
          fmw_product                 => $rcu_domain_template,
          oracle_fmw_product_home_dir => "${middleware_home_dir}/oracle_common",
          jdk_home_dir                => $jdk_home_dir,
          os_user                     => $os_user,
          os_group                    => $os_group,
          download_dir                => $download_dir,
          rcu_action                  => 'create',
          rcu_jdbc_url                => $repository_database_url,
          rcu_database_url            => $rcu_database_url,
          rcu_sys_user                => $repository_sys_user,
          rcu_sys_password            => $repository_sys_password,
          rcu_prefix                  => $repository_prefix,
          rcu_password                => $repository_password,
          rcu_honor_omf               => $rcu_honor_omf,
          rcu_temp_tablespace         => $rcu_temp_tablespace,
          rcu_tablespace              => $rcu_tablespace,
          rcu_soa_profile             => $rcu_soa_profile,
          logoutput                   => $logoutput,
          before                      => Exec["execwlst ${domain_name} ${title}"],
        }
      }
    }

    # create domain
    # On newer WebLogic versions domain creation also create's a template nodemanager.properties
    # because we create the correct nodemanager.properties later in the process by wlsInstall::nodemanager
    # we remove it over here.
    #
    if ($domain_template == 'bip') {
      exec { "execwlst ${domain_name} ${title}":
        command     => "${wlst_path}/config.sh -invPtrLoc ${ora_inst_path}/oraInst.loc -silent -responseFile ${download_dir}/bi-config-resp",
        environment => "JAVA_HOME=${jdk_home_dir}",
        unless      => "/usr/bin/test -e ${domain_dir}",
        creates     => $domain_dir,
        cwd         => $download_dir,
        timeout     => 0,
        path        => $exec_path,
        user        => $os_user,
        group       => $os_group,
        logoutput   => $logoutput,
        require     => File['bi-config'],
      }

      file { [ "${wls_domains_dir}/${domain_name}/servers", "${wls_domains_dir}/${domain_name}/servers/AdminServer",
            "${wls_domains_dir}/${domain_name}/servers/AdminServer/security" ]:
        ensure  => 'directory',
        owner   => $os_user,
        group   => $os_group,
        mode    => '0755',
        require => Exec["execwlst ${domain_name} ${title}"],
      }

      file { "${wls_domains_dir}/${domain_name}/servers/AdminServer/security/boot.properties":
        ensure  => file,
        owner   => $os_user,
        group   => $os_group,
        content => "password=${weblogic_password.unwrap}\nusername=${weblogic_user}",
        mode    => '0600',
        replace => false,
        require => File["${wls_domains_dir}/${domain_name}/servers/AdminServer/security"],
      }

    } else {
      exec { "execwlst ${domain_name} ${title}":
        command     => "${wlst_path}/wlst.sh domain_${domain_name}.py && /bin/rm -f ${domain_dir}/nodemanager/nodemanager.properties",
        environment => "JAVA_HOME=${jdk_home_dir}",
        unless      => "/usr/bin/test -e ${domain_dir}",
        creates     => $domain_dir,
        cwd         => $download_dir,
        timeout     => 0,
        path        => $exec_path,
        user        => $os_user,
        group       => $os_group,
        logoutput   => $logoutput,
        require     => [
          File["domain.py ${domain_name} ${title}"],
          File["${download_dir}/utils.py"],
          File[$domains_dir],
        ],
      }
    }

    if ( $extensions_template_file ) {
      exec { "execwlst ${domain_name} extension ${title}":
        command     => "${wlst_path}/wlst.sh domain_extension_${domain_name}.py && /bin/rm -f ${domain_dir}/nodemanager/nodemanager.properties",
        environment => "JAVA_HOME=${jdk_home_dir}",
        cwd         => $download_dir,
        timeout     => 0,
        path        => $exec_path,
        user        => $os_user,
        group       => $os_group,
        logoutput   => $logoutput,
        require     => [
          Exec["execwlst ${domain_name} ${title}"],
          File["domain_extension.py ${domain_name} ${title}"],
        ],
      }
    }

    unless defined(File[$wls_domains_file_location]) {
      file { $wls_domains_file_location:
        ensure => 'present',
        mode   => '0600',
        owner  => 'root',
        group  => $root_group,
      }
    }

    file_line { "domain entry for ${domain_name}":
      path    => $wls_domains_file_location,
      line    => "${domain_name}:${domain_dir}",
      require => Exec["execwlst ${domain_name} ${title}"],
    }

    if ( $domain_template == 'oim' ) {

      file { "${download_dir}/${title}psa_opss_upgrade.rsp":
        ensure    => present,
        content   => epp('wls_install/oim/psa_opss_upgrade.rsp.epp',{
          'rcu_database_url'        => $rcu_database_url,
          'repository_prefix'       => $repository_prefix,
          'repository_password'     => $repository_password,
          'repository_sys_password' => $repository_sys_password,
        }),
        mode      => '0775',
        owner     => $os_user,
        group     => $os_group,
        show_diff => false,
        backup    => false,
      }

      exec { "exec PSA OPSS store upgrade ${domain_name} ${title}":
        command   => "${middleware_home_dir}/oracle_common/bin/psa -response ${download_dir}/${title}psa_opss_upgrade.rsp",
        timeout   => 0,
        cwd       => $download_dir, # Added since psa binary saves and changes to current dir
        path      => $exec_path,
        user      => $os_user,
        group     => $os_group,
        logoutput => $logoutput,
        require   => [
          Exec["execwlst ${domain_name} ${title}"],
          Exec["execwlst ${domain_name} extension ${title}"],
          File["${download_dir}/${title}psa_opss_upgrade.rsp"],
        ],
      }

      exec { "execwlst create OPSS store ${domain_name} ${title}":
        command     => "${wlst_path}/wlst.sh ${middleware_home_dir}/Oracle_IDM1/common/tools/configureSecurityStore.py -d ${domain_dir} -m create -c IAM -p ${repository_password.unwrap}",
        environment => "JAVA_HOME=${jdk_home_dir}",
        timeout     => 0,
        path        => $exec_path,
        user        => $os_user,
        group       => $os_group,
        logoutput   => $logoutput,
        require     => [
          Exec["execwlst ${domain_name} ${title}"],
          Exec["execwlst ${domain_name} extension ${title}"],
          Exec["exec PSA OPSS store upgrade ${domain_name} ${title}"],
        ],
      }

      exec { "execwlst validate OPSS store ${domain_name} ${title}":
        command     => "${wlst_path}/wlst.sh ${middleware_home_dir}/Oracle_IDM1/common/tools/configureSecurityStore.py -d ${domain_dir} -m validate",
        environment => "JAVA_HOME=${jdk_home_dir}",
        timeout     => 0,
        path        => $exec_path,
        user        => $os_user,
        group       => $os_group,
        logoutput   => $logoutput,
        require     => [
          Exec["execwlst ${domain_name} ${title}"],
          Exec["execwlst ${domain_name} extension ${title}"],
          Exec["execwlst create OPSS store ${domain_name} ${title}"],
        ],
      }

    }

    if $::kernel == 'SunOS' {

      if ( $domain_template =~ /^osb/ ){

        exec { "setDebugFlagOnFalse ${domain_name} ${title}":
          command   => "sed -e's/debugFlag=\"true\"/debugFlag=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh > /tmp/domain.tmp && mv /tmp/domain.tmp ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep debugFlag=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => [
            Exec["execwlst ${domain_name} ${title}"],
            Exec["execwlst ${domain_name} extension ${title}"],
          ],
        }

        exec { "setOSBDebugFlagOnFalse ${domain_name} ${title}":
          command   => "sed -e's/ALSB_DEBUG_FLAG=\"true\"/ALSB_DEBUG_FLAG=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh > /tmp/domain2.tmp && mv /tmp/domain2.tmp ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep ALSB_DEBUG_FLAG=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => Exec["setDebugFlagOnFalse ${domain_name} ${title}"],
        }

        exec { "setDERBY_FLAGOnFalse ${domain_name} ${title}":
          command   => "sed -e's/DERBY_FLAG=\"true\"/DERBY_FLAG=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh > /tmp/domain3.tmp && mv /tmp/domain3.tmp ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep DERBY_FLAG=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => Exec["setOSBDebugFlagOnFalse ${domain_name} ${title}"],
        }

      }

    } else {

      if ( $domain_template =~ /^osb/ ) {

        exec { "setDebugFlagOnFalse ${domain_name} ${title}":
          command   => "sed -i -e's/debugFlag=\"true\"/debugFlag=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep debugFlag=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => [
            Exec["execwlst ${domain_name} ${title}"],
            Exec["execwlst ${domain_name} extension ${title}"],
          ],
        }

        exec { "setOSBDebugFlagOnFalse ${domain_name} ${title}":
          command   => "sed -i -e's/ALSB_DEBUG_FLAG=\"true\"/ALSB_DEBUG_FLAG=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep ALSB_DEBUG_FLAG=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => Exec["setDebugFlagOnFalse ${domain_name} ${title}"],
        }

        exec { "setDERBY_FLAGOnFalse ${domain_name} ${title}":
          command   => "sed -i -e's/DERBY_FLAG=\"true\"/DERBY_FLAG=\"false\"/g' ${domain_dir}/bin/setDomainEnv.sh",
          onlyif    => "/bin/grep DERBY_FLAG=\"true\" ${domain_dir}/bin/setDomainEnv.sh | /usr/bin/wc -l",
          path      => $exec_path,
          user      => $os_user,
          group     => $os_group,
          logoutput => $logoutput,
          require   => Exec["setOSBDebugFlagOnFalse ${domain_name} ${title}"],
        }

      }
    }

    if ($domain_template == 'bip') {
      cleanup { "${download_dir}/bi-config-resp": }
    } else {
      cleanup { ["${download_dir}/domain_${domain_name}.py", "${download_dir}/utils.py"]: }
    }

    if ( $extensions_template_file ) {
      cleanup { "${download_dir}/domain_extension_${domain_name}.py": }
    }
  }
}
