#
# wls_install::fact_caching
#
# @summary This class ensure's that the wls_install facts that can be cached, are cached with the correct settings.
# You can change all TTL settings for the facts if an other setting is more fitting for your setup.
#
# @param [Boolean] enabled
#    When set to true, this enables facter caching for the wls_install module facts.
#    Beware that you need to have Facter version 4.1.0 or higher to enabled this. When you set this value to true, automatically TTL settings for most of the wls_install facts are set to a default value. For most installations, the default settings are fine.
#    When you set this value to `true`, the [facter setting `force-dot-resolution`](https://tickets.puppetlabs.com/browse/PUP-11089) is enabled. You have to ensure that all of your facts keep on working with this setting.
#
# @param [Optional[String[1]]] product_version_ttl
#    The Time to Live for the `wls_install_homes.
#    product_version` part of the `wls_install_homes` fact.
#
# @param [Optional[String[1]]] opatch_version_ttl
#    The Time to Live for the `wls_install_homes.
#    opatch_version` part of the `wls_install_homes` fact.
#
# @param [Optional[String[1]]] installed_features_ttl
#    The Time to Live for the `wls_install_homes.
#    installed_features` part of the `wls_install_homes` fact.
#
# @param [Optional[String[1]]] running_domains_ttl
#    The Time to Live for the `wls_install_homes.
#    running_domains` part of the `wls_install_homes` fact.
#
# @param [Optional[String[1]]] installed_patches_ttl
#    The Time to Live for the `wls_install_homes.
#    installed_patches` part of the `wls_install_homes` fact.
#
# @param [Optional[String[1]]] wls_install_inventory_loc_ttl
#    The Time to Live for the `wls_install_inventory_loc` fact.
#
# @param [Optional[String[1]]] wls_install_domains_ttl
#    
#
# @param [Optional[String[1]]] ords_homes_ttl
#    The Time to Live for the `ords_homes` fact.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::fact_caching(
  Boolean             $enabled,
  Optional[String[1]] $product_version_ttl,
  Optional[String[1]] $opatch_version_ttl,
  Optional[String[1]] $installed_features_ttl,
  Optional[String[1]] $running_domains_ttl,
  Optional[String[1]] $installed_patches_ttl,
  Optional[String[1]] $wls_install_inventory_loc_ttl,
  Optional[String[1]] $wls_install_domains_ttl,
  Optional[String[1]] $ords_homes_ttl,
){
  if $enabled {
    include wls_install::clear_caches
    #
    # If enabled, we need to enable the force-dot-resolution
    # setting for facter.
    #
    fact_setting { 'force-dot-resolution':
      value => true,
    }

    fact_config { 'wls_install_homes.product_version':
      ttl => $product_version_ttl,
    }

    fact_config { 'wls_install_homes.opatch_version':
      ttl => $opatch_version_ttl,
    }

    fact_config { 'wls_install_homes.installed_features':
      ttl => $installed_features_ttl,
    }

    fact_config { 'wls_install_homes.running_domains':
      ttl => $running_domains_ttl,
    }

    fact_config { 'wls_install_homes.installed_patches':
      ttl => $installed_patches_ttl,
    }

    fact_config { 'wls_install_inventory_loc':
      ttl => $wls_install_inventory_loc_ttl,
    }

    fact_config { 'ords_homes':
      ttl => $ords_homes_ttl,
    }
  } else {
    #
    # On puppet versions older than V6, the required libs
    # for fact_config are not installed. Because it also doesn't
    # serve any purpose, we skip this part on those versions.
    #
    if versioncmp($clientversion, '6.0.0') != -1 {
      #
      # Disable fact caching for all wls_install facts
      #
      $wls_install_facts = [
        'wls_install_homes.product_version',
        'wls_install_homes.opatch_version',
        'wls_install_homes.installed_features',
        'wls_install_homes.running_domains',
        'wls_install_homes.installed_patches',
        'wls_install_inventory_loc',
        'ords_homes',
      ]

      fact_config { $wls_install_facts:
        ttl => absent,
      }
    }
  }
}

