#
# wls_install::fmw
#
# @summary 
# This defined type allows you to install the Fusion Middleware add-on software. It supports:- OSB- SOA Suite- WebTier (HTTP Server)- Oracle Identity Management- Web Center + ContentHere is an example on how you could use this:```puppetorawls::fmw{"osbPS6":  middleware_home_dir     => "/opt/oracle/middleware11gR1",  weblogic_home_dir       => "/opt/oracle/middleware11gR1/wlserver",  jdk_home_dir            => "/usr/java/jdk1.7.0_45",  oracle_base_home_dir    => "/opt/oracle",  fmw_product             => "osb",  # adf|soa|osb|oim|wc|wcc|web  fmw_file1               => "ofm_osb_generic_11.1.1.7.0_disk1_1of1.zip",  os_user                 => "oracle",  os_group                => "dba",  download_dir            => "/data/install",  source                  => "/vagrant",}```
#
# @param [Wls_install::Versions] version
#    The version that is installed in the used Oracle home.
#    Puppet uses this value to decide on version specific actions.
#
# @param [Stdlib::Absolutepath] weblogic_home_dir
#    Directory to use as WebLogic home.
#
# @param [Stdlib::Absolutepath] middleware_home_dir
#    Middleware home directory.
#
# @param [Optional[Stdlib::Absolutepath]] oracle_base_home_dir
#    A directory to use as Oracle base directory.
#
# @param [Optional[Stdlib::Absolutepath]] oracle_home_dir
#    A directory to be used as Oracle home directory for this software.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [Wls_install::Fmw_products] fmw_product
#    Type of Fusion Middleware Product you want to install.
#    Valid values are:
#    - adf
#    - soa
#    - soaqs
#    - osb
#    - wcc
#    - wc
#    - oim
#    - oam
#    - web
#    - webgate
#    - oud
#    - mft
#    - b2b
#    - forms
#
# @param [Optional[String[1]]] fmw_file1
#    First file of FMW distribution.
#
# @param [Optional[String[1]]] fmw_file2
#    Second file of FMW distribution.
#
# @param [Optional[String[1]]] fmw_file3
#    Third file of FMW distribution.
#
# @param [Optional[String[1]]] fmw_file4
#    Fourth file of FMW distribution.
#
# @param [Boolean] bpm
#    Boolean to determine if you want to enable BPM.
#
# @param [Boolean] healthcare
#    Boolean to determine if you want to enable healthcare.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [String[1]] source
#    Source for the operation.
#
# @param [Stdlib::Absolutepath] temp_directory
#    Directory to use for temporary files.
#
# @param [Enum['colocated', 'collocated', 'standalone']] ohs_mode
#    Type of OHS mode.
#    Valid values are:
#    - colocated
#    - collocated
#    - standalone
#
# @param [Optional[Stdlib::Absolutepath]] oracle_inventory_dir
#    The directory that contains the oracle inventory.
#    The default value is: `/oracle_base/oraInventory`
#
# @param [Optional[Stdlib::Absolutepath]] orainstpath_dir
#    Path where to find the oraint.
#    loc file.
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::fmw(
  Wls_install::Versions          $version              = lookup({name => 'wls_version', default_value => 1111}),
  Stdlib::Absolutepath           $weblogic_home_dir    = lookup({name => 'wls_weblogic_home_dir'}),
  Stdlib::Absolutepath           $middleware_home_dir  = lookup({name => 'wls_middleware_home_dir'}),
  Optional[Stdlib::Absolutepath] $oracle_base_home_dir = lookup({name => 'wls_oracle_base_home_dir'}),
  Optional[Stdlib::Absolutepath] $oracle_home_dir      = undef,
  Stdlib::Absolutepath           $jdk_home_dir         = lookup({name => 'wls_jdk_home_dir'}),
  Wls_install::Fmw_products      $fmw_product          = undef,
  Optional[String[1]]            $fmw_file1            = undef,
  Optional[String[1]]            $fmw_file2            = undef,
  Optional[String[1]]            $fmw_file3            = undef,
  Optional[String[1]]            $fmw_file4            = undef,
  Boolean                        $bpm                  = false,
  Boolean                        $healthcare           = false,
  String[1]                      $os_user              = lookup({name => 'wls_os_user'}),
  String[1]                      $os_group             = lookup({name => 'wls_os_group'}),
  Stdlib::Absolutepath           $download_dir         = lookup({name => 'wls_download_dir'}),
  String[1]                      $source               = lookup({name => 'wls_source', default_value => undef}),
  Stdlib::Absolutepath           $temp_directory       = lookup({name => 'wls_temp_dir', default_value => '/tmp'}),
  Enum[
    'colocated',
    'collocated',
    'standalone'
  ]                              $ohs_mode             = lookup({name => 'ohs_mode', default_value => 'collocated'}),
  Optional[Stdlib::Absolutepath] $oracle_inventory_dir = undef,
  Optional[Stdlib::Absolutepath] $orainstpath_dir      = lookup({name => 'orainstpath_dir', default_value => undef}),
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                              $logoutput            = lookup({name => 'logoutput', default_value => 'on_failure'}),
)
{
  if $::osfamily == 'windows' { fail 'This module does not support Windows'}

  $exec_path = "${jdk_home_dir}/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:"

  if ( $oracle_inventory_dir ) {
    $ora_inventory = "${oracle_inventory_dir}/oraInventory"
  } else {
    $ora_inventory = "${oracle_base_home_dir}/oraInventory"
  }

  case $::kernel {
    'Linux', 'AIX': {
      if ( $orainstpath_dir ){
        $ora_inst_path = $orainstpath_dir
      } else {
        $ora_inst_path = '/etc'
      }
      case $::architecture {
        'i386': {
          $install_dir = 'linux'
        }
        default: {
          $install_dir = 'linux64'
        }
      }
    }
    'SunOS': {
      $ora_inst_path = '/var/opt/oracle'
      case $::architecture {
        'i86pc': {
          $install_dir = 'intelsolaris'
        }
        default: {
          $install_dir = 'solaris'
        }
      }
    }
    default: {
      fail("Unrecognized operating system ${::kernel}, please use it on a Linux or SunOS host")
    }
  }


  #Sanitise the resource title so that it can safely be used in filenames and execs etc.
  #After converting all spaces to underscores, remove all non alphanumeric characters (allow hypens and underscores too)
  $convert_spaces_to_underscores = regsubst($title,'\s','_','G')
  $sanitised_title = regsubst ($convert_spaces_to_underscores,'[^a-zA-Z0-9_-]','','G')

  $info = lookup('wls_install::fmw::product_version_info', Hash)[$version][$fmw_product]
  #
  # Check if version product combination is supported
  #
  if $info == undef {
    fail("FMW product ${fmw_product} not supported for version ${version}")
  }

  #
  # All product and version specific data is read from module hiera data.
  #
  $fmw_silent_response_file = $info['fmw_silent_response_file']
  $total_file               = $info['total_files']
  $default_home             = $info['default_home']
  $type                     = $info['type']
  $bin_file1                = $info['bin_file1']
  $bin_file2                = $info['bin_file2']
  $bin_file3                = $info['bin_file3']
  $bin_file4                = $info['bin_file4']
  if ( $oracle_home_dir ) {
    $oracle_home = $oracle_home_dir
  } else {
    $oracle_home = "${middleware_home_dir}/${default_home}"
  }
  #
  #
  # Now manage some special stuff
  case $fmw_product {
    'soa': {
      if ( $bpm ) {
        $install_type = 'BPM'
      } else {
        $install_type = 'SOA Suite'
      }
    }
    'soaqs': {
      if ( $bpm ) {
        $install_type = 'BPM'
      } else {
        $install_type = 'SOA Suite'
      }
    }
    'b2b': {
      if ( $healthcare ) {
        $install_type = 'Healthcare'
      } else {
        $install_type = 'B2B'
      }
    }
    'web': {
      if ( $ohs_mode == 'standalone' ) {
        $install_type = 'Standalone HTTP Server (Managed independently of WebLogic server)'
      } else {
        $install_type = 'Collocated HTTP Server (Managed through WebLogic server)'
      }
    }
    default: {
      # Case is handled by load of hieradata
      $install_type = $info['install_type']
    }
  }

  # $fmw_files = delete_undef_values([$fmw_file1, $fmw_file2, $fmw_file3, $fmw_file4])
  # Doesn't work in Puppet 6. Issue https://tickets.puppetlabs.com/browse/MODULES-7835
  $fmw_files = [$fmw_file1, $fmw_file2, $fmw_file3, $fmw_file4].filter |$val| { $val =~ NotUndef }

  if ( empty($fmw_files) ) {
    $install_require = [ File["${download_dir}/${sanitised_title}_silent.rsp"], Wls_install::Utils::Orainst["create oraInst for ${name}"] ]
    $install_sanitised = "${download_dir}/${bin_file1}"
  } else {
    $install_require = [ File["${download_dir}/${sanitised_title}_silent.rsp"], Wls_install::Utils::Orainst["create oraInst for ${name}"], Archive["${download_dir}/${fmw_file1}"] ]
    $install_sanitised = "${download_dir}/${sanitised_title}/${bin_file1}"
  }

  #
  # Version specific setup
  #
  case $version {
    1036, 1111: {
      $command = "-silent -response ${download_dir}/${sanitised_title}_silent.rsp -waitforcompletion"
      $create_oracle_home = true
      $install_command = "/bin/sh -c 'unset DISPLAY;${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/runInstaller ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir} -Djava.io.tmpdir=${temp_directory}'"
      $install_creates = "${oracle_home}/OPatch"    }
    1112: {
      $command = "-silent -response ${download_dir}/${sanitised_title}_silent.rsp -waitforcompletion"
      $create_oracle_home = true
      $install_command = "/bin/sh -c 'unset DISPLAY;${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/runInstaller ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir} -Djava.io.tmpdir=${temp_directory}'"
      $install_creates = "${oracle_home}/OPatch"    }
    1212: {
      $command = "-silent -response ${download_dir}/${sanitised_title}_silent.rsp -waitforcompletion"
      if ( $type == 'java' ) {
        $install = "java -Djava.io.tmpdir=${temp_directory} -jar "
      }
      else {
        $install = ''
      }
      $create_oracle_home = false
      $install_command = "${install}${install_sanitised} ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir}"
      $install_creates = $oracle_home
    }
    1213: {
      $command = "-silent -response ${download_dir}/${sanitised_title}_silent.rsp -waitforcompletion"
      if ( $type == 'java' ) {
        $install = "java -Djava.io.tmpdir=${temp_directory} -jar "
      }
      else {
        $install = ''
      }
      $create_oracle_home = false
      $install_command = "${install}${install_sanitised} ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir}"
      $install_creates = $oracle_home
    }
    1221: {
      $command = "-silent -responseFile ${download_dir}/${sanitised_title}_silent.rsp"
      if ( $type == 'java' ) {
        $install = "java -Djava.io.tmpdir=${temp_directory} -jar "
      }
      else {
        $install = ''
      }
      $create_oracle_home = false
      $install_command = "${install}${install_sanitised} ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir}"
      $install_creates = $oracle_home
    }
    12211: {
      $command = "-silent -responseFile ${download_dir}/${sanitised_title}_silent.rsp"
      if ( $type == 'java' ) {
        $install = "java -Djava.io.tmpdir=${temp_directory} -jar "
      }
      else {
        $install = ''
      }
      $create_oracle_home = false
      $install_command = "${install}${install_sanitised} ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir}"
      $install_creates = $oracle_home
    }
    12212, 12213, 12214: {
      $command = "-silent -responseFile ${download_dir}/${sanitised_title}_silent.rsp"
      if ( $type == 'java' ) {
        $install = "java -Djava.io.tmpdir=${temp_directory} -jar "
      }
      else {
        $install = ''
      }
      $create_oracle_home = false
      $install_command = "${install}${install_sanitised} ${command} -invPtrLoc ${ora_inst_path}/oraInst.loc -ignoreSysPrereqs -jreLoc ${jdk_home_dir}"
      $install_creates = $oracle_home
    }
    default: {}
  }

  easy_type::debug_evaluation() # Show local variable on extended debug

  unless wls_install::fmw_installed($oracle_home, $fmw_product) {

    if ( $source ) {
      $mount_point = $source
    } else {
      $mount_point = 'puppet:///modules/wls_install/'
    }

    if ( $mount_point == $download_dir ) {
      $archive_cleanup = false
    } else {
      $archive_cleanup = true
    }

    wls_install::utils::orainst { "create oraInst for ${name}":
      ora_inventory_dir => $ora_inventory,
      os_group          => $os_group,
    }


    file { "${download_dir}/${sanitised_title}_silent.rsp":
      ensure    => present,
      content   => epp($fmw_silent_response_file,{
        'oracle_home'         => $oracle_home,
        'middleware_home_dir' => $middleware_home_dir,
        'install_type'        => $install_type,
        'weblogic_home_dir'   => $weblogic_home_dir,
      }),
      mode      => '0775',
      owner     => $os_user,
      group     => $os_group,
      backup    => false,
      show_diff => false,
      require   => Wls_install::Utils::Orainst["create oraInst for ${name}"],
    }

    unless ( defined(File["${download_dir}/${sanitised_title}"]) ) {
      file { "${download_dir}/${sanitised_title}":
        ensure => directory,
        owner  => $os_user,
        group  => $os_group,
        mode   => '0755',
      }
    }
    $cleanup_files = $fmw_files.map |$f| {"${download_dir}/${f}"}
    $fmw_files.each | $fmw_file | {
      $outfile = regsubst($fmw_file, '\.zip$', '')
      archive { "${download_dir}/${fmw_file}":
        ensure       => present,
        group        => $os_group,
        extract      => true,
        extract_path => "${download_dir}/${sanitised_title}",
        require      => Wls_install::Utils::Orainst["create oraInst for ${name}"],
        source       => "${mount_point}/${fmw_file}",
        temp_dir     => $temp_directory,
        user         => $os_user,
      }
    }

    if $::kernel == 'SunOS' {
      if $version != 1213 {
        if $fmw_product == 'soa' {
          exec { "add -d64 oraparam.ini ${sanitised_title}":
            command   => "sed -e's/JRE_MEMORY_OPTIONS=\" -Xverify:none\"/JRE_MEMORY_OPTIONS=\"-d64 -Xverify:none\"/g' ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini > ${temp_directory}/soa.tmp && mv ${temp_directory}/soa.tmp ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini",
            unless    => "grep 'JRE_MEMORY_OPTIONS=\"-d64' ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini",
            require   => Archive["${download_dir}/${fmw_file1}","${download_dir}/${fmw_file2}"],
            before    => Exec["install ${sanitised_title}"],
            path      => $exec_path,
            user      => $os_user,
            group     => $os_group,
            cwd       => $temp_directory,
            logoutput => $logoutput,
          }
        }
        if $fmw_product == 'osb' {
          exec { "add -d64 oraparam.ini ${sanitised_title}":
            command   => "sed -e's/\\[Oracle\\]/\\[Oracle\\]\\\nJRE_MEMORY_OPTIONS=\"-d64\"/g' ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini > ${temp_directory}/osb.tmp && mv ${temp_directory}/osb.tmp ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini",
            unless    => "grep 'JRE_MEMORY_OPTIONS=\"-d64\"' ${download_dir}/${sanitised_title}/Disk1/install/${install_dir}/oraparam.ini",
            require   => Archive["${download_dir}/${fmw_file1}"],
            before    => Exec["install ${sanitised_title}"],
            path      => $exec_path,
            user      => $os_user,
            group     => $os_group,
            cwd       => $temp_directory,
            logoutput => $logoutput,
          }
        }
      }
    }

    if ( $create_oracle_home ) {
      unless ( defined(File[$oracle_home]) ) {
        file { $oracle_home:
          ensure => 'directory',
          owner  => $os_user,
          group  => $os_group,
          before => Exec["install ${sanitised_title}"],
        }
      }
    }

    exec { "install ${sanitised_title}":
      command     => $install_command,
      environment => "TEMP=${temp_directory}",
      timeout     => 0,
      creates     => $install_creates,
      cwd         => $temp_directory,
      path        => $exec_path,
      user        => $os_user,
      group       => $os_group,
      logoutput   => $logoutput,
      require     => $install_require,
    }

    # Cleanup
    cleanup { $cleanup_files: }
    cleanup { ["${download_dir}/${sanitised_title}", "${download_dir}/${sanitised_title}_silent.rsp"]: }
    ## fix EditHttpConf in OHS Webgate
    if ( $version == 1112 and $fmw_product == 'webgate' ) {
      exec { "install ${sanitised_title} EditHttpConf1":
        command   => "unzip -o -j '${download_dir}/${sanitised_title}/Disk1/stage/Components/oracle.as.oam.webgate.ohs_linux64/11.1.2.2.0/1/DataFiles/filegroup1.jar' 'webgate/ohs/lib/libxmlengine.so' -d '${oracle_home}/webgate/ohs/lib/'",
        timeout   => 0,
        path      => $exec_path,
        user      => $os_user,
        group     => $os_group,
        logoutput => $logoutput,
        cwd       => $temp_directory,
        require   => Exec["install ${sanitised_title}"],
      }
      exec { "install ${sanitised_title} EditHttpConf2":
        command   => "unzip -o -j '${download_dir}/${sanitised_title}/Disk1/stage/Components/oracle.as.oam.webgate.ohs_linux64/11.1.2.2.0/1/DataFiles/filegroup1.jar' 'webgate/ohs/lib/webgate.so' -d '${oracle_home}/webgate/ohs/lib/'",
        timeout   => 0,
        path      => $exec_path,
        user      => $os_user,
        group     => $os_group,
        logoutput => $logoutput,
        cwd       => $temp_directory,
        require   => Exec["install ${sanitised_title}"],
      }
      exec { "install ${sanitised_title} EditHttpConf3":
        command   => "unzip -o -j '${download_dir}/${sanitised_title}/Disk1/stage/Components/oracle.as.oam.webgate.ohs_linux64/11.1.2.2.0/1/DataFiles/filegroup1.jar' 'webgate/ohs/tools/setup/InstallTools/EditHttpConf' -d '${oracle_home}/webgate/ohs/tools/setup/InstallTools/'",
        timeout   => 0,
        path      => $exec_path,
        user      => $os_user,
        group     => $os_group,
        logoutput => $logoutput,
        cwd       => $temp_directory,
        require   => Exec["install ${sanitised_title}"],
      }
      file { "${oracle_home}/webgate/ohs/tools/setup/InstallTools/EditHttpConf":
        ensure  => file,
        mode    => '0775',
        owner   => $os_user,
        group   => $os_group,
        backup  => false,
        require => Exec["install ${sanitised_title} EditHttpConf3"],
      }
    }
  }
}
