#
# wls_install::opatchupgrade
#
# @summary This defined type allows you to install specified opatch version.
# It will extract the ziop file you specify as `source` and run the Opatch installer to ensure the correct version of opatch is installed.
#
# @param [String[1]] opatch_version
#    The version of opatch you want ensure is installed on your system.
#    When there is a difference between the currently detected Opatch version and the version you specify here, Puppet will install the Opatch version that is in your zip file specified by the `source` parameter.
#    If however this zip file contains a different version, this class will not idempotent.
#
# @param [Stdlib::Absolutepath] oracle_home_dir
#    A directory to be used as Oracle home directory for this software.
#
# @param [String[1]] patch_file
#    The zip file containing the required Opatch version.
#
# @param [String[1]] source
#    Source for the operation.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [Stdlib::Absolutepath] temp_directory
#    Directory to use for temporary files.
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::opatchupgrade(
  String[1]            $opatch_version,
  Stdlib::Absolutepath $oracle_home_dir,
  String[1]            $patch_file,
  String[1]            $source                    = lookup({name => 'wls_source', default_value => undef}),
  String[1]            $os_user                   = lookup({name => 'wls_os_user', default_value => undef}),
  String[1]            $os_group                  = lookup({name => 'wls_os_group', default_value => undef}),
  Stdlib::Absolutepath $jdk_home_dir              = lookup({name => 'wls_jdk_home_dir'}),
  Stdlib::Absolutepath $download_dir              = lookup({name => 'wls_download_dir', default_value => undef}),
  Stdlib::Absolutepath $temp_directory            = '/tmp',
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                    $logoutput                 = lookup({name => 'logoutput', default_value => 'on_failure'}),
)
{
  $convert_spaces_to_underscores = regsubst($title,'\s','_','G')
  $sanitised_title = regsubst ($convert_spaces_to_underscores,'[^a-zA-Z0-9_-]','','G')
  $opatch_jar_file = "${download_dir}/${sanitised_title}/6880880/opatch_generic.jar"

  #
  # check the current opatch version. If The home is not(yet) available,
  # make the current version empty. This will always install the opatch.
  #
  $home_installed = $::wls_install_homes.dig('installed_features',$oracle_home_dir) != undef
  if $home_installed {
    $installed_version = $::wls_install_homes.dig('opatch_version',$oracle_home_dir)
  } else {
    $installed_version = ''
  }

  easy_type::debug_evaluation() # Show local variable on extended debug

  #
  # If the current installed version is the same as the requested one,
  # don't do anything.
  #
  if $installed_version != $opatch_version {
    #
    # if we use a NFS share, don't delete the archive.
    #
    if ( $source == $download_dir ) {
      $archive_cleanup = false
    } else {
      $archive_cleanup = true
    }

    file { "${download_dir}/${sanitised_title}":
      ensure => 'directory',
      owner  => $os_user,
      group  => $os_group,
    }

    #
    # Download and extrat the archive
    #
    -> archive { "${download_dir}/${patch_file}":
      ensure       => present,
      cleanup      => $archive_cleanup,
      creates      => $opatch_jar_file,
      user         => $os_user,
      group        => $os_group,
      extract      => true,
      extract_path => "${download_dir}/${sanitised_title}",
      source       => "${source}/${patch_file}",
      temp_dir     => $temp_directory,
    }

    -> exec { "install opatch upgrade ${title}":
      command     => "${jdk_home_dir}/bin/java -jar ${opatch_jar_file} -silent oracle_home=${oracle_home_dir}",
      environment => ['JAVA_VENDOR=Sun', "JAVA_HOME=${jdk_home_dir}"],
      timeout     => 0,
      user        => $os_user,
      group       => $os_group,
      logoutput   => $logoutput,
    }
  }
}
