#
# wls_install::storeuserconfig
#
# @summary This defined type allows you to create a user config for WLST , this way you don't need to know the weblogic password.
# Here is an example on how you could use this:
# 
# ```puppet
# ora_install::storeuserconfig{'Wls12c':
#   domain_name                => "Wls12c",
#   adminserver_address        => "localhost",
#   adminserver_port           => 7001,
#   weblogic_password          => "weblogic1",
#   user_config_dir            => '/home/oracle',
#   logoutput                 => false,
# }
# ```
#
# @param [String[1]] domain_name
#    The domain name.
#
# @param [Stdlib::Absolutepath] weblogic_home_dir
#    Directory to use as WebLogic home.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [String[1]] adminserver_address
#    The address of the admin server.
#    May be a DNS name or a physical IP address.
#
# @param [Integer] adminserver_port
#    The IP port the admin server is listening on.
#
# @param [Stdlib::Absolutepath] user_config_dir
#    Directory where to store the user configs.
#
# @param [String[1]] weblogic_user
#    The base WebLogic username to configure.
#
# @param [Easy_type::Password] weblogic_password
#    The password of the base WebLogic user name.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::storeuserconfig (
  String[1]            $domain_name         = lookup({name => 'domain_name'}),
  Stdlib::Absolutepath $weblogic_home_dir   = lookup({name => 'wls_weblogic_home_dir'}),
  Stdlib::Absolutepath $jdk_home_dir        = lookup({name => 'wls_jdk_home_dir'}),
  String[1]            $adminserver_address = lookup({name => 'domain_adminserver_address', default_value => 'localhost'}),
  Integer              $adminserver_port    = lookup({name => 'domain_adminserver_port', default_value => 7001}),
  Stdlib::Absolutepath $user_config_dir     = undef,
  String[1]            $weblogic_user       = lookup({name => 'wls_weblogic_user', default_value => 'weblogic'}),
  Easy_type::Password  $weblogic_password   = lookup({name => 'domain_wls_password'}),
  String[1]            $os_user             = lookup({name => 'wls_os_user'}),
  String[1]            $os_group            = lookup({name => 'wls_os_group'}),
  Stdlib::Absolutepath $download_dir        = lookup({name => 'wls_download_dir'}),
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                    $logoutput           = lookup({name => 'logoutput', default_value => 'on_failure'}),
)
{
  easy_type::debug_evaluation() # Show local variable on extended debug

  # the py script used by the wlst*-
  file { "${download_dir}/${title}storeUserConfig.py":
    ensure    => present,
    path      => "${download_dir}/${title}storeUserConfig.py",
    content   => epp('wls_install/wlst/storeUserConfig.py.epp',{
      'weblogic_user'       => $weblogic_user,
      'adminserver_address' => $adminserver_address,
      'adminserver_port'    => $adminserver_port,
      'domain_name'         => $domain_name,
      'os_user'             => $os_user,
      'user_config_dir'     => $user_config_dir,
    }),
    backup    => false,
    show_diff => false,
    replace   => true,
    mode      => '0555',
    owner     => $os_user,
    group     => $os_group,
  }

  $java_command = 'java -Dweblogic.management.confirmKeyfileCreation=true -Dweblogic.security.SSL.ignoreHostnameVerification=true weblogic.WLST -skipWLSModuleScanning '
  $exec_path   = "${jdk_home_dir}/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:"

  exec { "execwlst ${title}storeUserConfig.py":
    command     => "${java_command} ${download_dir}/${title}storeUserConfig.py ${weblogic_password.unwrap}",
    environment => [
      "CLASSPATH=${weblogic_home_dir}/server/lib/weblogic.jar",
      "JAVA_HOME=${jdk_home_dir}"
    ],
    unless      => "ls -l ${user_config_dir}/${os_user}-${domain_name}-WebLogicConfig.properties",
    path        => $exec_path,
    user        => $os_user,
    group       => $os_group,
    logoutput   => $logoutput,
    require     => File["${download_dir}/${title}storeUserConfig.py"],
  }

}
